# filename: display.py
# -*- coding: utf-8 -*-
import time
import Adafruit_GPIO.SPI as SPI
import Adafruit_Nokia_LCD as LCD
import pi
import my_weather
import requests
from PIL import Image
from PIL import ImageDraw
from PIL import ImageFont
from bs4 import BeautifulSoup

get_ip_url = 'http://icanhazip.com/'
get_ip_time: str = str()  # 更新ip时间
ip: str = str()
get_weather_time: str = str()
weather: list = list()
max_height = 5  # 屏幕显示的最大行数

# Raspberry Pi hardware SPI config:
DC = 23
RST = 24
SPI_PORT = 0
SPI_DEVICE = 0


def get_my_ip() -> str:
    """
    每天更新一次公网IP地址
    :return:
    """
    global get_ip_time, ip
    today_date = time.strftime("%y-%m-%d", time.localtime())
    if today_date == get_ip_time or get_ip_time != "":
        return str(ip)
    else:
        get_ip_time = today_date
        ip = BeautifulSoup(requests.get(get_ip_url).content, "html.parser", from_encoding='gbk')
        return str(ip)


def get_weather() -> list:
    """
    每小时更新一次天气情况
    :return:
    """
    global get_weather_time, weather

    now_hour: str = time.strftime("%y-%m-%d %H", time.localtime())
    if now_hour == get_weather_time or get_weather_time != "":  # 查看天气更新没有
        return weather
    else:
        tmp, pm25, pm10 = my_weather.main()  # 温度, pm2.5, pm10
        text = 'TEMP:%s' % tmp
        pm25_text = 'PM2.5:%s' % pm25
        pm10_text = 'PM10:%s' % pm10
        current_weather = list([str(text), str(pm25_text), str(pm10_text)])

        get_weather_time = now_hour
        weather = current_weather
        return weather


def split_content(content) -> list:
    """
    5110只能显示五行数据，如果超过六行，做分割
    :param content:
    :return:
    """
    temp_list = list()
    if len(content) > max_height:
        i = 1
        while i < len(content):
            temp: list = list([content[0]])  # 先把时间append
            while len(temp) < max_height and i < len(content):
                temp.append(content[i])
                i = i + 1
            temp_list.append(temp)
    else:
        temp_list.append(content)
    return temp_list


def draw_text(wait_to_draw_content):
    # Hardware SPI usage:
    disp = LCD.PCD8544(DC, RST, spi=SPI.SpiDev(SPI_PORT, SPI_DEVICE, max_speed_hz=4000000))
    # Initialize library.
    disp.begin(contrast=60)

    # Clear display.
    disp.clear()
    disp.display()

    # Create blank image for drawing.
    # Make sure to create image with mode '1' for 1-bit color.

    image = Image.new('1', (LCD.LCDWIDTH, LCD.LCDHEIGHT))

    # Get drawing object to draw on image.
    draw = ImageDraw.Draw(image)

    # Draw a white filled box to clear the image.
    draw.rectangle((0, 0, LCD.LCDWIDTH, LCD.LCDHEIGHT), outline=255, fill=255)

    # Load default font.
    font = ImageFont.load_default()

    for each in wait_to_draw_content:
        text = each
        # 根据传进来的字符串进行x轴的确定, 5110宽84 高48, 一个字符宽6个像素点
        x_pos = 42 - (len(text) * 6 / 2)
        if x_pos < 0:
            x_pos = 0

        # 一共传进来几个数据就依次从中间开始显示
        y_base = int((6 - len(wait_to_draw_content)) / 2)
        # y_pos = y_base * 8 + draw_content.index(each) * 8 - 8
        y_pos = 8 * (y_base + wait_to_draw_content.index(each))

        draw.text((x_pos, y_pos), text, font=font)

    # Display image.
    disp.image(image)
    disp.display()
    

if __name__ == '__main__':
    try:
        while True:
            now_time = time.strftime("%y-%m-%d %H:%M", time.localtime())
            draw_content = [now_time, str(get_my_ip())]

            now_weather = get_weather()
            draw_content.extend(now_weather)

            pi_info: list = pi.main(all=True)  # 返回CPU温度和使用率
            draw_content.extend(pi_info)

            draw_content = split_content(draw_content)
            for each in draw_content:
                draw_text(each)  # 注意消息不要超过六条
                time.sleep(5)
    except KeyboardInterrupt as e:
        print("exit...")
