# filename: pi.py
# -*- coding: utf-8 -*-
# 读取树莓派信息
import os


# Return CPU temperature as a character string
def getCPUtemperature():
    res = os.popen('/usr/bin/vcgencmd measure_temp').readline()
    return res.replace("temp=", "").replace("'C\n", "")

# Return % of CPU used by user as a character string
def getCPUuse():
    return str(os.popen(r"/usr/bin/top -n 1 -b| /usr/bin/awk '/Cpu\(s\):/ {print $2}'").readline().strip())


# Return RAM information (unit=kb) in a list
# Index 0: total RAM
# Index 1: used RAM
# Index 2: free RAM
def getRAMinfo():
    p = os.popen('free')
    i = 0
    while 1:
        i = i + 1
        line = p.readline()
        if i == 2:
            return line.split()[1:4]


# Return information about disk space as a list (unit included)
# Index 0: total disk space
# Index 1: used disk space
# Index 2: remaining disk space
# Index 3: percentage of disk used
def getDiskSpace():
    p = os.popen("df -h /")
    i = 0
    while 1:
        i = i + 1
        line = p.readline()
        if i == 2:
            return line.split()[1:5]


def main(all=False, cpu=True, ram=False, disk=False) -> list:
    pi = list()
    if all:
        cpu = True
        ram = True
        disk = True
    if cpu:
        CPU_temp = getCPUtemperature()
        CPU_usage = getCPUuse()
        cpu_tmp = 'CPU TMP:%s' % CPU_temp
        cpu_usg = 'CPU USE:%s' % CPU_usage
        # pi = list([str(cpu_tmp), str(cpu_usg)])
        pi.append(str(cpu_tmp))
        pi.append(str(cpu_usg))
    if ram:
        RAM_stats = getRAMinfo()
        RAM_total = round(int(RAM_stats[0]) / 1000, 1)
        RAM_used = round(int(RAM_stats[1]) / 1000, 1)
        RAM_free = round(int(RAM_stats[2]) / 1000, 1)
        RAM_total = 'RAM|All:' + str(RAM_total)
        RAM_used = 'RAM|Used:' + str(RAM_used)
        RAM_free = 'RAM|Free:' + str(RAM_free)
        pi.append(RAM_total)
        pi.append(RAM_used)
        pi.append(RAM_free)
    if disk:
        # Disk information
        DISK_stats = getDiskSpace()
        DISK_total = DISK_stats[0]
        DISK_used = DISK_stats[1]
        DISK_perc = DISK_stats[3]
        DISK_total = 'DISK|Size:' + str(DISK_total)
        DISK_used = 'DISK|Used:' + str(DISK_used)
        DISK_perc = 'DISK|Used:' + str(DISK_perc)
        pi.append(DISK_total)
        pi.append(DISK_used)
        pi.append(DISK_perc)
    return pi
